@@ -6,7 +6,9 @@
  */
 
 #include "common.h"
+#if APIVERSNUM < 10507
 #include "i18n.h"
+#endif
 #include "manager.h"
 #include "menuburn.h"
 #include "menuitems.h"
