@@ -34,8 +34,8 @@ bool cDebugLog::Open(void)
 
 void cDebugLog::Close(void)
 {
-  if(File)
-    fclose(File);
+//  if(File)
+//    fclose(File);
 }
 
 bool cDebugLog::SetLogFile(char *filename)
