@@ -11,7 +11,7 @@
 
 using namespace std;
 
-static const char *VERSION        = "1.2";
+static const char *VERSION        = "1.2-am1";
 static const char *DESCRIPTION    = tr("Extended recordings menu");
 static const char *MAINMENUENTRY  = "ExtRecMenu";
 
@@ -74,6 +74,8 @@ bool cPluginExtrecmenu::Start(void)
 
   MoveCutterThread=new WorkerThread();
 
+  RecordingDirCommands.Load(AddDirectory(cPlugin::ConfigDirectory(PLUGIN_NAME_I18N), "dircmds.conf"), true);
+
   return true;
 }
 
