@@ -1,5 +1,7 @@
 #include <vdr/menu.h>
 
+extern cCommands RecordingDirCommands;
+
 class mySetup
 {
  public:
@@ -18,6 +20,7 @@ class mySetup
   int UseVDRsRecInfoMenu;
   int PatchFont;
   int FileSystemFreeMB;
+  int UseCutterQueue;
 };
 
 extern mySetup mysetup;
@@ -40,6 +43,7 @@ class myMenuSetup:public cMenuSetupPage
   int usevdrsrecinfomenu;
   int patchfont;
   int filesystemfreemb;
+  int usecutterqueue;
  protected:
   virtual void Store();
  public:
