@@ -22,6 +22,7 @@
 #include "visual.h"
 //#include "i18n.h"
 #include "vars.h"
+#include "icons.h"
 
 static const char *allVdrFonts[] = {
 #ifdef HAVE_FREETYPE
@@ -36,7 +37,7 @@ static const char *allVdrFonts[] = {
 
 const char *sourcesSub=0;
 
-static const char *VERSION       = "0.3.0-rc2";
+static const char *VERSION       = "0.4.0-b3";
 static const char *DESCRIPTION   = trNOOP("Enhanced audioplayer");
 static const char *MAINMENUENTRY = trNOOP("Musicplayer");
 
@@ -179,9 +180,11 @@ bool cPluginMp3::ProcessArgs(int argc, char *argv[])
   return true;
 }
 
-
 bool cPluginMp3::Start(void)
 {
+
+  Icons::InitCharSet();
+
   if(MP3VisLoader.LoadVis("current.vis")) {
     MP3VisLoader.SetVis();
     isyslog("music: loaded visualization data");
@@ -190,7 +193,6 @@ bool cPluginMp3::Start(void)
     MP3Setup.EnableVis = 0;
     esyslog("music: ERROR: problems to load visualization data! -- enable cover");
   }    
-  
 
   return true;
 }
@@ -231,11 +233,14 @@ bool cPluginMp3::Initialize(void)
   if(MP3Sources.Count()<1) {
      esyslog("music: ERROR: you should have defined at least one source in musicsources.conf");
      fprintf(stderr,"No source(s) defined in musicsources.conf\n");
-     return false;
      }
 
-  InfoCache.Load(false);
 
+//  if(!MP3Setup.First_Time_Run) {
+//    isyslog("music: load cache...");
+    InfoCache.Load(false);
+//  }
+  
 #if VDRVERSNUM < 10507
   RegisterI18n(Phrases);
 #endif
@@ -249,6 +254,44 @@ bool cPluginMp3::Initialize(void)
   d(printf("music: using %s\n",mad_version))
   d(printf("music: compiled with %s\n",MAD_VERSION))
 
+/*  
+  if(MP3Setup.First_Time_Run) {
+
+    printf("music: first time run. scanning library...\n");
+    cFileSource *src=MP3Sources.GetSource();
+    printf("cFileSource.first()\n");	
+    if(src) {
+      printf("src = true\n");	
+      isyslog("music: load cache...");
+      cFileObj *item=new cFileObj(src,0,0,otBase);
+      printf("item=new FileObj\n");	
+      if(item) {
+        printf("item->exists()\n");	
+	    cInstantPlayList *pl=new cInstantPlayList(item);
+        printf("pl=new cInstantPlaylist(item)\n");	
+	    if(pl && pl->Load() && pl->Count()) {
+          printf("pl && pl->load=true\n");	
+		  mgr->Add(pl);
+          printf("mgr->Added\n");	
+	      delete item;
+          printf("delete item and return true\n");
+          MP3Setup.First_Time_Run = false;		  
+		  return true;
+		  }
+	    else {
+          printf("try to delete pl\n");	
+		  delete pl;
+          printf("pl deleted\n");	
+        }
+	  }
+      printf("try to delete item\n");	
+      delete item;	
+      printf("item deleted\n");	
+    }  
+  }
+*/  
+  
+  
   return true;
 }
 
@@ -264,7 +307,13 @@ const char *cPluginMp3::MainMenuEntry(void)
 
 cOsdObject *cPluginMp3::MainMenuAction(void)
 {
-
+/*
+  if(MP3Setup.First_Time_Run) {
+    isyslog("music: music library is scanning");
+	Skins.Message(mtInfo, "First time run: Scan music library", 5);
+	return false;
+  }	
+*/  
   if(!SetLanguage(I18nLanguageCode(I18nCurrentLanguage()))) {
     esyslog("music: could not set language: %s . Set default 'eng,dos'", I18nLanguageCode(I18nCurrentLanguage()));
     langdir = strdup("language/english");
@@ -326,12 +375,12 @@ bool cPluginMp3::SetupParse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "AudioMode"))        MP3Setup.AudioMode       = atoi(Value);
   else if (!strcasecmp(Name, "BgrScan"))          MP3Setup.BgrScan         = atoi(Value);
   else if (!strcasecmp(Name, "EditorMode"))       MP3Setup.EditorMode      = atoi(Value);
-  else if (!strcasecmp(Name, "DisplayMode"))      MP3Setup.DisplayMode     = atoi(Value);
   else if (!strcasecmp(Name, "UseDeviceStillPicture"))       MP3Setup.UseDeviceStillPicture      = atoi(Value);
   else if (!strcasecmp(Name, "MenuMode"))         MP3Setup.MenuMode        = atoi(Value);
   else if (!strcasecmp(Name, "TargetLevel"))      MP3Setup.TargetLevel     = atoi(Value);
   else if (!strcasecmp(Name, "LimiterLevel"))     MP3Setup.LimiterLevel    = atoi(Value);
   else if (!strcasecmp(Name, "Only48kHz"))        MP3Setup.Only48kHz       = atoi(Value);
+  else if (!strcasecmp(Name, "ConnectTimeout"))   MP3Setup.ConnectTimeout  = atoi(Value);
   else if (!strcasecmp(Name, "UseProxy"))         MP3Setup.UseProxy        = atoi(Value);
   else if (!strcasecmp(Name, "ProxyHost"))        strn0cpy(MP3Setup.ProxyHost,Value,MAX_HOSTNAME);
   else if (!strcasecmp(Name, "ProxyPort"))        MP3Setup.ProxyPort       = atoi(Value);
@@ -348,32 +397,33 @@ bool cPluginMp3::SetupParse(const char *Name, const char *Value)
       }
 #endif
     }
-  else if (!strcasecmp(Name, "HideMainMenu"))       	MP3Setup.HideMainMenu              = atoi(Value);
-  else if (!strcasecmp(Name, "KeepSelect"))         	MP3Setup.KeepSelect                = atoi(Value);
-  else if (!strcasecmp(Name, "AutoPurge"))         	MP3Setup.AutoPurge                 = atoi(Value);
-  else if (!strcasecmp(Name, "ExitClose"))         	MP3Setup.ExitClose                 = atoi(Value);
-  else if (!strcasecmp(Name, "BgrMode"))         	MP3Setup.BgrMode                   = atoi(Value);
-  else if (!strcasecmp(Name, "ShowMessages"))         	MP3Setup.ShowMessages              = atoi(Value);
-  else if (!strcasecmp(Name, "AdminMode"))         	MP3Setup.AdminMode                 = atoi(Value);
+  else if (!strcasecmp(Name, "HideMainMenu"))           MP3Setup.HideMainMenu              = atoi(Value);
+  else if (!strcasecmp(Name, "KeepSelect"))             MP3Setup.KeepSelect                = atoi(Value);
+//  else if (!strcasecmp(Name, "AutoPurge"))              MP3Setup.AutoPurge                 = atoi(Value);
+  else if (!strcasecmp(Name, "ExitClose"))         	    MP3Setup.ExitClose                 = atoi(Value);
+  else if (!strcasecmp(Name, "BgrMode"))         	    MP3Setup.BgrMode                   = atoi(Value);
+  else if (!strcasecmp(Name, "ShowMessage"))            MP3Setup.ShowMessage               = atoi(Value);
+  else if (!strcasecmp(Name, "AdminMode"))         	    MP3Setup.AdminMode                 = atoi(Value);
   else if (!strcasecmp(Name, "EnableRating"))         	MP3Setup.EnableRating              = atoi(Value);
-  else if (!strcasecmp(Name, "RateCompat"))         	strn0cpy(MP3Setup.RateCompat,Value,sizeof(MP3Setup.RateCompat));
-  else if (!strcasecmp(Name, "RateInFile"))         	MP3Setup.RateInFile                = atoi(Value);
-  else if (!strcasecmp(Name, "RatingFirst"))         	MP3Setup.RatingFirst               = atoi(Value);
-  else if (!strcasecmp(Name, "Jumptime"))          	MP3Setup.Jumptime                  = atoi(Value);
-  else if (!strcasecmp(Name, "CopyDir"))           	strn0cpy(MP3Setup.CopyDir,Value,sizeof(MP3Setup.CopyDir));
-  else if (!strcasecmp(Name, "RecordDir"))           	strn0cpy(MP3Setup.RecordDir,Value,sizeof(MP3Setup.RecordDir));
+  else if (!strcasecmp(Name, "RateCompat"))             strn0cpy(MP3Setup.RateCompat,Value,sizeof(MP3Setup.RateCompat));
+  else if (!strcasecmp(Name, "RateInFile"))             MP3Setup.RateInFile                = atoi(Value);
+  else if (!strcasecmp(Name, "RatingFirst"))            MP3Setup.RatingFirst               = atoi(Value);
+  else if (!strcasecmp(Name, "Jumptime"))          	    MP3Setup.Jumptime                  = atoi(Value);
+  else if (!strcasecmp(Name, "CopyDir"))           	    strn0cpy(MP3Setup.CopyDir,Value,sizeof(MP3Setup.CopyDir));
+  else if (!strcasecmp(Name, "RecordDir"))              strn0cpy(MP3Setup.RecordDir,Value,sizeof(MP3Setup.RecordDir));
   else if (!strcasecmp(Name, "RecordOpts"))           	strn0cpy(MP3Setup.RecordOpts,Value,sizeof(MP3Setup.RecordOpts));
-  else if (!strcasecmp(Name, "CoverDir"))           	strn0cpy(MP3Setup.CoverDir,Value,sizeof(MP3Setup.CoverDir));
+  else if (!strcasecmp(Name, "CoverDir"))               strn0cpy(MP3Setup.CoverDir,Value,sizeof(MP3Setup.CoverDir));
   else if (!strcasecmp(Name, "ReplaceString"))          strn0cpy(MP3Setup.ReplaceString,Value,sizeof(MP3Setup.ReplaceString));
-  else if (!strcasecmp(Name, "OSDoffsetx"))        	MP3Setup.OSDoffsetx                = atoi(Value);
-  else if (!strcasecmp(Name, "OSDoffsety"))        	MP3Setup.OSDoffsety                = atoi(Value);
-  else if (!strcasecmp(Name, "UseOneArea"))        	MP3Setup.UseOneArea                = atoi(Value);
-  else if (!strcasecmp(Name, "Rowcount"))        	MP3Setup.Rowcount                  = atoi(Value);
+  else if (!strcasecmp(Name, "OSDoffsetx"))           	MP3Setup.OSDoffsetx                = atoi(Value);
+  else if (!strcasecmp(Name, "OSDoffsety"))        	    MP3Setup.OSDoffsety                = atoi(Value);
+  else if (!strcasecmp(Name, "UseOneArea"))        	    MP3Setup.UseOneArea                = atoi(Value);
+  else if (!strcasecmp(Name, "Rowcount"))        	    MP3Setup.Rowcount                  = atoi(Value);
   else if (!strcasecmp(Name, "ArtistFirst"))            MP3Setup.ArtistFirst               = atoi(Value);
   else if (!strcasecmp(Name, "Coversize"))              MP3Setup.Coversize                 = atoi(Value);
   else if (!strcasecmp(Name, "MaxCover"))               MP3Setup.MaxCover                  = atoi(Value);
   else if (!strcasecmp(Name, "ImgAlpha"))               MP3Setup.ImgAlpha                  = atoi(Value);
   else if (!strcasecmp(Name, "ImgDither"))              MP3Setup.ImgDither                 = atoi(Value);
+  else if (!strcasecmp(Name, "UseFastResponse"))        MP3Setup.UseFastResponse           = atoi(Value);
   else if (!strcasecmp(Name, "EnableVis"))              MP3Setup.EnableVis                 = atoi(Value);
   else if (!strcasecmp(Name, "VisInCoverMode"))         MP3Setup.VisInCoverMode            = atoi(Value);
   else if (!strcasecmp(Name, "FalloffSA"))              MP3Setup.FalloffSA                 = atoi(Value);
@@ -381,20 +431,25 @@ bool cPluginMp3::SetupParse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "MaxCacheFill"))           MP3Setup.MaxCacheFill              = atoi(Value);
   else if (!strcasecmp(Name, "ImgTreeDepth"))           MP3Setup.ImgTreeDepth              = atoi(Value);
 #endif
+  else if (!strcasecmp(Name, "First_Time_Run"))         MP3Setup.First_Time_Run            = atoi(Value);
   else if (!strcasecmp(Name, "FontTop"))                MusicConfig.SetFont(FONT_TOP, atoi(Value));
   else if (!strcasecmp(Name, "FontTopName"))            MusicConfig.SetFont(FONT_TOP, Value);
+  else if (!strcasecmp(Name, "FontInterpret"))          MusicConfig.SetFont(FONT_INTERPRET, atoi(Value));
+  else if (!strcasecmp(Name, "FontInterpretName"))      MusicConfig.SetFont(FONT_INTERPRET, Value);
+  else if (!strcasecmp(Name, "FontGenre"))              MusicConfig.SetFont(FONT_GENRE, atoi(Value));
+  else if (!strcasecmp(Name, "FontGenreName"))          MusicConfig.SetFont(FONT_GENRE, Value);
   else if (!strcasecmp(Name, "FontStatus"))             MusicConfig.SetFont(FONT_STATUS, atoi(Value));
   else if (!strcasecmp(Name, "FontStatusName"))         MusicConfig.SetFont(FONT_STATUS, Value);
-  else if (!strcasecmp(Name, "FontList"))               MusicConfig.SetFont(FONT_LIST, atoi(Value));
-  else if (!strcasecmp(Name, "FontListName"))           MusicConfig.SetFont(FONT_LIST, Value);
-  else if (!strcasecmp(Name, "FontListActive"))         MusicConfig.SetFont(FONT_LISTACTIVE, atoi(Value));
-  else if (!strcasecmp(Name, "FontListActiveName"))     MusicConfig.SetFont(FONT_LISTACTIVE, Value);
-  else if (!strcasecmp(Name, "FontTitle"))              MusicConfig.SetFont(FONT_TITLE, atoi(Value));
-  else if (!strcasecmp(Name, "FontTitleName"))          MusicConfig.SetFont(FONT_TITLE, Value);
   else if (!strcasecmp(Name, "FontInfo"))               MusicConfig.SetFont(FONT_INFO, atoi(Value));
   else if (!strcasecmp(Name, "FontInfoName"))           MusicConfig.SetFont(FONT_INFO, Value);
-  else if (!strcasecmp(Name, "FontBottom"))             MusicConfig.SetFont(FONT_BOTTOM, atoi(Value));
-  else if (!strcasecmp(Name, "FontBottomName"))         MusicConfig.SetFont(FONT_BOTTOM, Value);
+  else if (!strcasecmp(Name, "FontTitle"))              MusicConfig.SetFont(FONT_TITLE, atoi(Value));
+  else if (!strcasecmp(Name, "FontTitleName"))          MusicConfig.SetFont(FONT_TITLE, Value);
+  else if (!strcasecmp(Name, "FontList"))               MusicConfig.SetFont(FONT_LIST, atoi(Value));
+  else if (!strcasecmp(Name, "FontListName"))           MusicConfig.SetFont(FONT_LIST, Value);
+  else if (!strcasecmp(Name, "FontButton"))             MusicConfig.SetFont(FONT_BUTTON, atoi(Value));
+  else if (!strcasecmp(Name, "FontButtonName"))         MusicConfig.SetFont(FONT_BUTTON, Value);
+  else if (!strcasecmp(Name, "FontSymbol"))             MusicConfig.SetFont(FONT_SYMBOL, atoi(Value));
+  else if (!strcasecmp(Name, "FontSymbolName"))         MusicConfig.SetFont(FONT_SYMBOL, Value);
   else return false;
 
   return true;
@@ -425,7 +480,7 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   userlevel[1]=tr("Admin");
   userlevel[2]=tr("Superadmin");
   Add(new cMenuEditStraItem(tr("Setup.MP3$Userlevel"),                        &MP3Setup.AdminMode,        3   ,userlevel));
-  Add(new cMenuEditBoolItem(tr("Setup.MP3$Show statusmessages"),              &MP3Setup.ShowMessages));
+  Add(new cMenuEditBoolItem(tr("Setup.MP3$Show statusmessages"),              &MP3Setup.ShowMessage));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Jump interval (FFW/FREW)"),         &MP3Setup.Jumptime,         1   ,360));
   Add(new cMenuEditStrItem( tr("Setup.MP3$Where to copy tracks"),              MP3Setup.CopyDir,        255));
   Add(new cMenuEditStrItem( tr("Setup.MP3$Where to record streams"),           MP3Setup.RecordDir,      255));
@@ -446,6 +501,7 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Use Dithering for cover"),    &MP3Setup.ImgDither));
   Add(new cMenuEditIntItem(tr("Setup.MP3$Max. download of cover"),      &MP3Setup.MaxCover,1,50));
 
+  Add(new cMenuEditBoolItem(tr("Setup.MP3$Enable fast responsetime"),   &MP3Setup.UseFastResponse));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Enable visualization"),       &MP3Setup.EnableVis));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Show visualization in covermode"),    &MP3Setup.VisInCoverMode));
   Add(new cMenuEditIntItem(tr("Setup.MP3$Visualization bar falloff"),   &MP3Setup.FalloffSA,  0, 20));
@@ -459,13 +515,12 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   Add(new cMenuEditStraItem(tr("Setup.MP3$Audio output mode"),          &amode,numModes,aout));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Audio mode"),                 &MP3Setup.AudioMode, tr("Round"), tr("Dither")));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Use 48kHz mode only"),        &MP3Setup.Only48kHz));
-  Add(new cMenuEditIntItem( tr("Setup.MP3$Display mode"),               &MP3Setup.DisplayMode, 1, 5));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Live picture in background"), &MP3Setup.BgrMode));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Use DeviceStillPicture"),     &MP3Setup.UseDeviceStillPicture));
-  Add(new cMenuEditBoolItem(tr("Setup.MP3$Initial loop mode"),          &MP3Setup.InitLoopMode));
-  Add(new cMenuEditBoolItem(tr("Setup.MP3$Initial shuffle mode"),       &MP3Setup.InitShuffleMode));
+//  Add(new cMenuEditBoolItem(tr("Setup.MP3$Initial loop mode"),          &MP3Setup.InitLoopMode));
+//  Add(new cMenuEditBoolItem(tr("Setup.MP3$Initial shuffle mode"),       &MP3Setup.InitShuffleMode));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Abort player at end of list"),&MP3Setup.AbortAtEOL));
-  Add(new cMenuEditBoolItem(tr("Setup.MP3$Purge before save cache"),    &MP3Setup.AutoPurge));
+//  Add(new cMenuEditBoolItem(tr("Setup.MP3$Purge before save cache"),    &MP3Setup.AutoPurge));
   scan[0]=tr("disabled");
   scan[1]=tr("ID3 only");
   scan[2]=tr("ID3 & Level");
@@ -480,6 +535,9 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   Add(new cMenuEditBoolItem(tr("Hide mainmenu entry"),             &MP3Setup.HideMainMenu));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Normalizer level"),      &MP3Setup.TargetLevel, 0, MAX_TARGET_LEVEL));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Limiter level"),         &MP3Setup.LimiterLevel, MIN_LIMITER_LEVEL, 100));
+
+  Add(new cMenuEditIntItem(tr("Setup.MP3$Connection timeout (s)"), &MP3Setup.ConnectTimeout, 1, 60));
+
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Use HTTP proxy"),        &MP3Setup.UseProxy));
   Add(new cMenuEditStrItem( tr("Setup.MP3$HTTP proxy host"),       MP3Setup.ProxyHost,MAX_HOSTNAME,allowed));
   Add(new cMenuEditIntItem( tr("Setup.MP3$HTTP proxy port"),       &MP3Setup.ProxyPort,1,65535));
@@ -494,6 +552,12 @@ cMenuSetupMP3::cMenuSetupMP3(void)
 
 void cMenuSetupMP3::Store(void)
 {
+#ifdef DEBUG
+  printf("music: save setup\n");
+  printf("music: InitLoopMode = %d\n", MP3Setup.InitLoopMode);
+  printf("music: InitShuffleMode = %d\n", MP3Setup.InitShuffleMode);
+#endif
+
   MusicConfig = data;
 
   MP3Setup.AudioOutMode=amodes[amode];
@@ -504,12 +568,12 @@ void cMenuSetupMP3::Store(void)
   SetupStore("AudioOutMode",     MP3Setup.AudioOutMode   );
   SetupStore("BgrScan",          MP3Setup.BgrScan        );
   SetupStore("EditorMode",       MP3Setup.EditorMode     );
-  SetupStore("DisplayMode",      MP3Setup.DisplayMode    );
   SetupStore("UseDeviceStillPicture", MP3Setup.UseDeviceStillPicture );
   SetupStore("MenuMode",         MP3Setup.MenuMode       );
   SetupStore("TargetLevel",      MP3Setup.TargetLevel    );
   SetupStore("LimiterLevel",     MP3Setup.LimiterLevel   );
   SetupStore("Only48kHz",        MP3Setup.Only48kHz      );
+  SetupStore("ConnectTimeout",   MP3Setup.ConnectTimeout );
   SetupStore("UseProxy",         MP3Setup.UseProxy       );
   SetupStore("ProxyHost",        MP3Setup.ProxyHost      );
   SetupStore("ProxyPort",        MP3Setup.ProxyPort      );
@@ -517,12 +581,12 @@ void cMenuSetupMP3::Store(void)
   SetupStore("CddbHost",         MP3Setup.CddbHost       );
   SetupStore("CddbPort",         MP3Setup.CddbPort       );
   SetupStore("AbortAtEOL",       MP3Setup.AbortAtEOL     );
-  SetupStore("AutoPurge",        MP3Setup.AutoPurge      );
+//  SetupStore("AutoPurge",        MP3Setup.AutoPurge      );
   SetupStore("HideMainMenu",     MP3Setup.HideMainMenu   );
   SetupStore("KeepSelect",       MP3Setup.KeepSelect     );
   SetupStore("ExitClose",        MP3Setup.ExitClose      );
   SetupStore("BgrMode",          MP3Setup.BgrMode        );
-  SetupStore("ShowMessages",     MP3Setup.ShowMessages   );
+  SetupStore("ShowMessage",      MP3Setup.ShowMessage   );
   SetupStore("AdminMode",        MP3Setup.AdminMode      );
   SetupStore("EnableRating",     MP3Setup.EnableRating   );
   SetupStore("RateCompat",       MP3Setup.RateCompat     );
@@ -543,12 +607,14 @@ void cMenuSetupMP3::Store(void)
   SetupStore("MaxCover",         MP3Setup.MaxCover       );
   SetupStore("ImgAlpha",         MP3Setup.ImgAlpha       );
   SetupStore("ImgDither",        MP3Setup.ImgDither      );
+  SetupStore("UseFastResponse",  MP3Setup.UseFastResponse);
   SetupStore("EnableVis",        MP3Setup.EnableVis      );
   SetupStore("VisInCoverMode",   MP3Setup.VisInCoverMode);
   SetupStore("FalloffSA",        MP3Setup.FalloffSA);
 #ifdef HAVE_MAGICK
   SetupStore("MaxCacheFill",     MP3Setup.MaxCacheFill   );
   SetupStore("ImgTreeDepth",     MP3Setup.ImgTreeDepth   );
+  SetupStore("First_Time_Run",   MP3Setup.First_Time_Run );
 #endif
 
 
@@ -763,13 +829,15 @@ void cMenuSetupFonts::Set(void)
   Clear();
 
   int numAvailFonts = sizeof(allVdrFonts)/sizeof(char*);
-  Add(new cMenuEditStraItem(tr("User"),                  &data->allFonts[FONT_TOP].VdrId, numAvailFonts, allVdrFonts));
-  Add(new cMenuEditStraItem(tr("Artist"),                &data->allFonts[FONT_STATUS].VdrId, numAvailFonts, allVdrFonts));
-  Add(new cMenuEditStraItem(tr("Tracklist"),             &data->allFonts[FONT_LIST].VdrId, numAvailFonts, allVdrFonts));
-//  Add(new cMenuEditStraItem(tr("Cursor"),                &data->allFonts[FONT_LISTACTIVE].VdrId, numAvailFonts, allVdrFonts));
-  Add(new cMenuEditStraItem(tr("Title"),                 &data->allFonts[FONT_TITLE].VdrId, numAvailFonts, allVdrFonts));
-  Add(new cMenuEditStraItem(tr("Songinfo"),              &data->allFonts[FONT_INFO].VdrId, numAvailFonts, allVdrFonts));
-  Add(new cMenuEditStraItem(tr("Hotkeys"),               &data->allFonts[FONT_BOTTOM].VdrId, numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Top"),               &data->allFonts[FONT_TOP].VdrId      , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Artist"),            &data->allFonts[FONT_INTERPRET].VdrId, numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Genre"),             &data->allFonts[FONT_GENRE].VdrId    , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Status"),            &data->allFonts[FONT_STATUS].VdrId   , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Info"),              &data->allFonts[FONT_INFO].VdrId     , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Title"),             &data->allFonts[FONT_TITLE].VdrId    , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("List"),              &data->allFonts[FONT_LIST].VdrId     , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Buttons"),           &data->allFonts[FONT_BUTTON].VdrId   , numAvailFonts, allVdrFonts));
+  Add(new cMenuEditStraItem(tr("Symbols"),           &data->allFonts[FONT_SYMBOL].VdrId   , numAvailFonts, allVdrFonts));
 
   SetCurrent(Get(current));
   Display();
@@ -788,7 +856,7 @@ bool cPluginMp3::ExternalPlay(const char *path, bool test)
 {
   char real[PATH_MAX+1];
   if(realpath(path,real)) {
-    cFileSource *src=MP3Sources.FindSource(real);
+    cFileSource *src=MP3Sources.FindSource(real , true);
     if(src) {
       cFileObj *item=new cFileObj(src,0,0,otFile);
       if(item) {
@@ -821,14 +889,14 @@ bool cPluginMp3::ExternalPlay(const char *path, bool test)
 
 bool cPluginMp3::Service(const char *Id, void *Data)
 {
-  if(strcmp(Id,"Music-Play-v1") == 0) {
+  if(strcmp(Id, "Music-Play-v1") == 0) {
     if(Data) {
       struct MPlayerServiceData *msd=(struct MPlayerServiceData *)Data;
       msd->result=ExternalPlay(msd->data.filename,false);
       }
     return true;
     }
-  else if(strcmp(Id,"Music-Test-v1") == 0) {
+  else if(strcmp(Id, "Music-Test-v1") == 0) {
     if(Data) {
       struct MPlayerServiceData *msd=(struct MPlayerServiceData *)Data;
       msd->result=ExternalPlay(msd->data.filename,true);
@@ -848,6 +916,7 @@ bool cPluginMp3::Service(const char *Id, void *Data)
     }
     return true;
   }
+  
   return false;
 }
 
