@@ -9,27 +9,16 @@
 #include "decoder.h"
 #include "mp3id3.h"
 #include "mp3control.h"
+#include "config.h"
 #include "skin.h"
 #include "vars.h"
+#include "icons.h"
 
 #define X_DISPLAY_MISSING
 
 // ------------ cMP3SearchBrowseItem ------------------------------------------------------------------------------------------------ //
-
-class cMP3SearchBrowseItem : public cOsdItem {
-private:
- cFileObj *item;
- virtual void SetID3(void);
- int idx;
- int total;
- int bitrate;
- const char *artist;
- const char *title;
-public:
- cMP3SearchBrowseItem(cFileObj *Item, int index, const char *Artist, const char *Title, const char *Bitrate, const char *Total);
- cFileObj *Item(void) {return item;}
- void NewName(void);
-};
+int RateFrom;
+int RateTo;
 
 cMP3SearchBrowseItem::cMP3SearchBrowseItem(cFileObj *Item, int index, const char *Artist, const char *Title, const char *Bitrate, const char *Total) {
   item      = Item;
@@ -42,21 +31,20 @@ cMP3SearchBrowseItem::cMP3SearchBrowseItem(cFileObj *Item, int index, const char
   SetID3();
 }
 
+/*
+cMP3SearchBrowseItem::~cMP3SearchBrowseItem()
+{
+
+}
+*/
 
 void cMP3SearchBrowseItem::SetID3(void) {
   char *Name;
 
-#ifdef HAVE_TTF_CHARS
   if(MP3Setup.ArtistFirst) 
-    asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", "\u00FA", artist, title, bitrate/1000, total/60, total%60);
-  else 
-    asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", "\u00FA", title, artist, bitrate/1000, total/60, total%60);
-#else
-  if(MP3Setup.ArtistFirst) 
-    asprintf(&Name, "%04d \t %s - %s \t  %3d k    \t%02d:%02d", idx, artist, title, bitrate/1000, total/60, total%60);
-  else 
-    asprintf(&Name, "%04d \t %s - %s \t  %3d k    \t%02d:%02d", idx, title, artist, bitrate/1000, total/60, total%60);
-#endif
+    asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", Icons::Menu_Checkbox(), artist, title, bitrate/1000, total/60, total%60);
+  else
+    asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", Icons::Menu_Checkbox(), title, artist, bitrate/1000, total/60, total%60);
 
   SetText(Name,false);
 }
@@ -71,30 +59,17 @@ void cMP3SearchBrowseItem::NewName(void) {
 
   if(!si) si=song->Info();
 
-#ifdef HAVE_TTF_CHARS
   if(si && si->Title) {
     if(MP3Setup.ArtistFirst) 
-      asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", "\u00F9", si->Artist, si->Title,si->Bitrate/1000, si->Total/60, si->Total%60);
+      asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", Icons::Menu_CheckedBox(), si->Artist, si->Title,si->Bitrate/1000, si->Total/60, si->Total%60);
     else 
-      asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", "\u00F9", si->Title, si->Artist, si->Bitrate/1000, si->Total/60, si->Total%60);
+      asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", Icons::Menu_CheckedBox(), si->Title, si->Artist, si->Bitrate/1000, si->Total/60, si->Total%60);
     }
   else {
-      asprintf(&Name, "%s \t <%s> \t               \t         ", "\u00F9", song->Name());
+      asprintf(&Name, "%s \t <%s> \t               \t         ", Icons::Menu_CheckedBox(), song->Name());
   } 
-#else
-  if(si && si->Title) {
-    if(MP3Setup.ArtistFirst) 
-      asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", "<<  ", si->Artist, si->Title,si->Bitrate/1000, si->Total/60, si->Total%60);
-    else 
-      asprintf(&Name, "%s \t %s - %s \t  %3d k    \t%02d:%02d", "<<  ", si->Title, si->Artist, si->Bitrate/1000, si->Total/60, si->Total%60);
-    }
-  else {
-      asprintf(&Name, "%s \t <%s> \t               \t         ", "<<  ", song->Name());
-  } 
-#endif
  
   SetText(Name,false);
-
 }
 
 
@@ -103,7 +78,6 @@ void cMP3SearchBrowseItem::NewName(void) {
 
 cFileObj *cMP3SearchResult::selected=0;
 
-
 cMP3SearchResult::cMP3SearchResult(const char *szTitle)
 :cOsdMenu(szTitle ,GetTab(1), GetTab(2), GetTab(3), GetTab(4)) //, GetTab(5))
 {
@@ -130,7 +104,7 @@ cFileObj *cMP3SearchResult::CurrentItem(void) {
 
 
 void cMP3SearchResult::SetHelp() {
-  cOsdMenu::SetHelp(tr("Parent"),tr("Add"),tr("Add all"),tr("ID3info"));
+  cOsdMenu::SetHelp(tr("Parent"),tr("Add"),tr("Add all"),tr("Sort"));
 }
 
 
@@ -145,8 +119,8 @@ int cMP3SearchResult::GetTab(int Tab)
 
 
 int cMP3SearchResult::LoadResult() {
-
- using namespace std;
+  
+  using namespace std;
   std::string SongTitle("");
   std::string Base("");
   std::string basesource("");
@@ -160,7 +134,7 @@ int cMP3SearchResult::LoadResult() {
   bool result = false;
   std::string filename("");
   int  Length;
- 
+
   basesource = BaseSource;
   Length = basesource.length();
   
@@ -241,6 +215,7 @@ int cMP3SearchResult::LoadResult() {
 
 }
 
+
 eOSState cMP3SearchResult::ID3Info(void) {
   cFileObj *item=CurrentItem();
   if(item && item->Type()==otFile) {
@@ -313,31 +288,34 @@ eOSState cMP3SearchResult::ProcessKey(eKeys Key) {
   if (state == osUnknown) {
     switch (Key) {
 
-      case kUp:
-      case kUp|k_Repeat:
-      case kDown:
-      case kDown|k_Repeat:
-	  break;
+		case kUp:
+		case kUp|k_Repeat:
+		case kDown:
+		case kDown|k_Repeat:
+			break;
 
-      case kRed:
-	  return osBack;
-	break;
+		case kRed:
+			return osBack;
+			break;
 
-      case kGreen:	  
-          state = AddOne();
-	break;
+		case kGreen:	  
+			state = AddOne();
+			break;
 
-      case kYellow:
-           state = AddAll();
-        break;
+		case kYellow:
+			state = AddAll();
+			break;
 
-      case kBlue:
-      case kOk:
-           state = ID3Info();
-	break;   
+		case kBlue:
+			state = ID3Info();
+			break;
 
-      default:
-           state = osContinue;
+		case kOk:
+			state = ID3Info();
+			break; 
+
+		default:
+			state = osContinue;
     }
   }
   
@@ -350,7 +328,7 @@ eOSState cMP3SearchResult::ProcessKey(eKeys Key) {
 char *cMP3SearchRatingTo::ratingto = NULL;
 
 cMP3SearchRatingTo::cMP3SearchRatingTo(void)
-:cOsdMenu(tr("Rating to"))
+:cOsdMenu(tr("Rating to"),15)
 {
   free(ratingto); ratingto=0;
   SetHelp();
@@ -365,25 +343,90 @@ void cMP3SearchRatingTo::SetHelp(void) {
     cOsdMenu::SetHelp(tr("Parent"),NULL,NULL,tr("Select"));
 }
 
+cOsdItem *cMP3SearchRatingTo::Item(const char *text)
+{
+  char *buf=0;
+  asprintf(&buf,"%s",text?text:"");
+  cOsdItem *item = new cOsdItem(buf,osUnknown,true);
+  free(buf);
+  Add(item); return item;
+}
+
+
 void cMP3SearchRatingTo::LoadItems(void)
 {
-  std::ifstream in;
-  std::string Datei;
-  std::string line;
-  
-  Datei = config;
-  Datei = Datei + "/" + langdir;
-  Datei = Datei + "/data/ratingsearchtext.dat";
+  std::string rate2text;
 
-  in.open (Datei.c_str());
-  
-  if(in) {
-    while ((getline(in,line,'\n'))) {
-      Add(new cOsdItem(hk(line.c_str())));
-    }
+  rate2text = tr("No value");
+  Item(rate2text.c_str());
 
-    in.close();
-  }
+  rate2text = tr("Not rated");
+  Item(rate2text.c_str());
+  
+  rate2text = Icons::Menu_Bomb();
+  rate2text = rate2text + "\t" + tr("Song can be deleted");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("Makes me nervous");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("Bad song");
+  Item(rate2text.c_str());
+  
+  
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("Useful for certain cause");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("I hear it from time to time");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("New song, don't know");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("Not bad...not good");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("Good song");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("Very good song");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("I love this song");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("One of my favourites");
+  Item(rate2text.c_str());
 
   Display();
 }
@@ -394,7 +437,10 @@ void cMP3SearchRatingTo::GetValue(void)
   cOsdItem *item = (cOsdItem*)Get(Current());
 
   if(item) {
-    ratingto = strdup(itoa(Current())); 
+    RateTo = Current() -2;
+// DEBUG
+	printf("RateTo = %d\n", RateTo);
+    ratingto = strdup(item->Text()); 
   }
 
 }
@@ -432,7 +478,7 @@ eOSState cMP3SearchRatingTo::ProcessKey(eKeys Key)
 char *cMP3SearchRatingFrom::ratingfrom = NULL;
 
 cMP3SearchRatingFrom::cMP3SearchRatingFrom(void)
-:cOsdMenu(tr("Rating from"))
+:cOsdMenu(tr("Rating from"),15)
 {
   free(ratingfrom); ratingfrom=0;
   SetHelp();
@@ -447,25 +493,89 @@ void cMP3SearchRatingFrom::SetHelp(void) {
     cOsdMenu::SetHelp(tr("Parent"),NULL,NULL,tr("Select"));
 }
 
+cOsdItem *cMP3SearchRatingFrom::Item(const char *text)
+{
+  char *buf=0;
+  asprintf(&buf,"%s",text?text:"");
+  cOsdItem *item = new cOsdItem(buf,osUnknown,true);
+  free(buf);
+  Add(item); return item;
+}
+
 void cMP3SearchRatingFrom::LoadItems(void)
 {
-  std::ifstream in;
-  std::string Datei;
-  std::string line;
-  
-  Datei = config;
-  Datei = Datei + "/" + langdir;
-  Datei = Datei + "/data/ratingsearchtext.dat";
+  std::string rate2text;
 
-  in.open (Datei.c_str());
-  
-  if(in) {
-    while ((getline(in,line,'\n'))) {
-      Add(new cOsdItem(hk(line.c_str())));
-    }
+  rate2text = tr("No value");
+  Item(rate2text.c_str());
 
-    in.close();
-  }
+  rate2text = tr("Not rated");
+  Item(rate2text.c_str());
+  
+  rate2text = Icons::Menu_Bomb();
+  rate2text = rate2text + "\t" + tr("Song can be deleted");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("Makes me nervous");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("Bad song");
+  Item(rate2text.c_str());
+  
+  
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("Useful for certain cause");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("I hear it from time to time");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("New song, don't know");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("Not bad...not good");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("Good song");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("Very good song");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Half_Star();
+  rate2text = rate2text + "\t" + tr("I love this song");
+  Item(rate2text.c_str());
+
+  rate2text = Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + Icons::Menu_Full_Star();
+  rate2text = rate2text + "\t" + tr("One of my favourites");
+  Item(rate2text.c_str());
 
   Display();
 }
@@ -476,7 +586,10 @@ void cMP3SearchRatingFrom::GetValue(void)
   cOsdItem *item = (cOsdItem*)Get(Current());
 
   if(item) {
-    ratingfrom = strdup(itoa(Current()));
+    RateFrom = Current() -2;
+// DEBUG
+	  printf("RateFrom = %d\n", RateFrom);
+    ratingfrom = strdup(item->Text());
   }
 
 }
@@ -596,7 +709,7 @@ eOSState cMP3SearchGenre::ProcessKey(eKeys Key)
 //---------------- cMP3Search --------------------------------------------------------------------------------------------------------------------------
 
 cMP3Search::cMP3Search(const char *Name)
-:cOsdMenu(tr("Music: Search"),20)
+:cOsdMenu(tr("Music: Search"),30)
 {
   strncpy(Artist, Name, sizeof(Artist));
   updateGenre=updateRatingFrom=updateRatingTo=false;
@@ -609,6 +722,7 @@ cMP3Search::~cMP3Search()
 
 void cMP3Search::ShowDisplay(void)
 {
+  char *buf=0;
   
   Clear();
       
@@ -622,8 +736,13 @@ void cMP3Search::ShowDisplay(void)
   Add(new cMenuEditStrItem(tr("Filename")        ,FullFile    , sizeof(FullFile)-1 ));
   Add(new cMenuEditIntItem(tr("Year from")       ,&YearFrom   , -1     , 2030));
   Add(new cMenuEditIntItem(tr("Year to")         ,&YearTo     , -1     , 2030));
-  Add(new cMenuEditIntItem(tr("Rating from")     ,&RatingFrom , -1     , 10));
-  Add(new cMenuEditIntItem(tr("Rating to")       ,&RatingTo   , -1     , 10));
+  asprintf(&buf, "%s\t%s", tr("Rating from"), RatingFrom);
+  Add(new cOsdItem(hk(buf)));
+  asprintf(&buf, "%s\t%s", tr("Rating to"), RatingTo);
+  Add(new cOsdItem(hk(buf)));
+  free(buf);
+  //  Add(new cMenuEditStraItem(tr("Rating from")    ,RatingFrom  , sizeof(RatingFrom)-1));
+//  Add(new cMenuEditStraItem(tr("Rating to")      ,RatingTo    , sizeof(RatingTo)-1));
   Item("");
   Add(new cMenuEditBoolItem(tr("Only available songs") ,&Exist      ,tr("no"), tr("yes")));
 
@@ -659,9 +778,9 @@ void cMP3Search::SaveSearch(void) {
   
   if(FILE* fd=fopen(Datei.c_str(), "w")) {
     char *query;
-    asprintf(&query, "%s\n%s\n%s\n%s\n%d\n%d\n%d\n%d\n%d",Artist,Title,Genre,FullFile,YearFrom,YearTo,RatingFrom,RatingTo,Exist);
+    asprintf(&query, "%s\n%s\n%s\n%s\n%d\n%d\n%s\n%s\n%d\n%d\n%d",Artist,Title,Genre,FullFile,YearFrom,YearTo,RatingFrom,RatingTo,RateFrom,RateTo,Exist);
     fprintf(fd, query);
-    d(printf("music: search: Save query '%s'\n",query));
+    d(printf("music: search: Save query: \n%s\n",query));
     free(query);
     
     fclose(fd);
@@ -677,7 +796,20 @@ eOSState cMP3Search::Searching(void) {
 
   SaveSearch();    
 
-  if(InfoCache.SearchUp(Artist, Title , Genre, FullFile, YearFrom, YearTo, RatingFrom, RatingTo, Exist)) {
+#ifdef DEBUG
+printf("Artist: '%s'\n", Artist);
+printf("Title: '%s'\n", Title);
+printf("Genre: '%s'\n", Genre);
+printf("Filename: '%s'\n", FullFile);
+printf("Year from: '%d'\n", YearFrom);
+printf("Year to: '%d'\n", YearTo);
+printf("Rating from: '%d'\n", RateFrom);
+printf("Rating to: '%d'\n", RateTo);
+printf("File exist: '%d'\n", Exist);
+
+#endif  
+  
+  if(InfoCache.SearchUp(Artist, Title , Genre, FullFile, YearFrom, YearTo, RateFrom, RateTo, Exist)) {
     char *buf;
     asprintf(&buf,"%s %i", tr("Found:"), InfoCache.expr1);
     d(printf("music: search: %s of %i\n", buf, InfoCache.expr2));
@@ -752,8 +884,10 @@ void cMP3Search::PreviousSearch(void) {
   std::string pFullFile;
   std::string pYearFrom;
   std::string pYearTo;
-  std::string pRankingFrom;
-  std::string pRankingTo;
+  std::string pRatingFrom;
+  std::string pRatingTo;
+  std::string pRateFrom;
+  std::string pRateTo;
   std::string pPlayable;
   
   pDatei = BaseSource;
@@ -777,11 +911,15 @@ void cMP3Search::PreviousSearch(void) {
        else
       if(i==5) pYearTo=line;
        else
-      if(i==6) pRankingFrom=line;
+      if(i==6) pRatingFrom=line;
        else
-      if(i==7) pRankingTo=line;
+      if(i==7) pRatingTo=line;
        else
-      if(i==8) pPlayable=line;
+      if(i==8) pRateFrom=line;
+       else
+      if(i==9) pRateTo=line;
+       else
+      if(i==10) pPlayable=line;
 
       i++;
     }
@@ -795,8 +933,12 @@ void cMP3Search::PreviousSearch(void) {
   strncpy(FullFile , pFullFile.c_str() ,sizeof(FullFile));
   YearFrom        = atoi(pYearFrom.c_str());
   YearTo          = atoi(pYearTo.c_str());
-  RatingFrom      = atoi(pRankingFrom.c_str());
-  RatingTo        = atoi(pRankingTo.c_str());
+  strncpy(RatingFrom, pRatingFrom.c_str() ,sizeof(RatingFrom));
+  strncpy(RatingTo  , pRatingTo.c_str()    ,sizeof(RatingTo));
+  RateFrom        = atoi(pRateFrom.c_str());
+  RateTo          = atoi(pRateTo.c_str());
+// Get here the string from file
+
   Exist           = atoi(pPlayable.c_str());
 
   ShowDisplay();
@@ -811,8 +953,10 @@ void cMP3Search::NewValues(void) {
   strncpy(FullFile ,"" ,sizeof(FullFile));
   YearFrom        =-1;
   YearTo          =-1;
-  RatingFrom      =-1;
-  RatingTo        =-1;
+  strncpy(RatingFrom ,tr("No value") ,sizeof(RatingFrom));
+  strncpy(RatingTo   ,tr("No value") ,sizeof(RatingTo));
+  RateFrom        =-2;
+  RateTo          =-2;
   Exist           =0;
 
   ShowDisplay();
@@ -827,8 +971,10 @@ void cMP3Search::ClearValues(void) {
   strncpy(FullFile ,"" ,sizeof(FullFile));
   YearFrom        =-1;
   YearTo          =-1;
-  RatingFrom      =-1;
-  RatingTo        =-1;
+  strncpy(RatingFrom ,tr("No value") ,sizeof(RatingFrom));
+  strncpy(RatingTo   ,tr("No value") ,sizeof(RatingTo));
+  RateFrom        =-2;
+  RateTo          =-2;
   Exist           =0;
 
   ShowDisplay();
@@ -850,7 +996,7 @@ void cMP3Search::SetRatingFrom(void) {
 
   const char *newrating=cMP3SearchRatingFrom::RatingFrom();
   if(newrating) {
-    RatingFrom = atoi(newrating);
+    strncpy(RatingFrom, newrating, sizeof(RatingFrom));
   }
 
   ShowDisplay();
@@ -861,7 +1007,7 @@ void cMP3Search::SetRatingTo(void) {
 
   const char *newrating=cMP3SearchRatingTo::RatingTo();
   if(newrating) {
-    RatingTo = atoi(newrating);
+    strncpy(RatingTo, newrating, sizeof(RatingTo));
   }    
 
   ShowDisplay();
