@@ -37,22 +37,32 @@ cN2Timer::cN2Timer(void)
   cycles=0; ctrl=0; divisor=1; remainder=-1; latch=0xFF;
 }
 
-void cN2Timer::AddCycles(unsigned int count)
+bool cN2Timer::AddCycles(unsigned int count)
 {
+  bool irq=false;
   if(Running()) {
+    bool stop=false;
     remainder+=count;
     if(remainder>=divisor) {
       cycles-=remainder/divisor;
       remainder%=divisor;
       }
+    if(cycles<0 || (cycles==0 && remainder>=2))
+      stop=true;
     if(ctrl&tmCONTINUOUS) {
       while(cycles<0) cycles+=latch+1;
       }
-    else if(cycles<0 || (cycles==0 && remainder>=4)) {
+    else if(stop) {
+      PRINTF(L_SYS_EMU,"n2timer %d: timer stop (cycles=%d remainder=%d)",nr,cycles,remainder);
       cycles=0;
       Stop();
       }
+    if((ctrl&tmINTERRUPT) && stop) {
+      PRINTF(L_SYS_EMU,"n2timer %d: IRQ triggered",nr);
+      irq=true;
+      }
     }
+  return irq;
 }
 
 void cN2Timer::Latch(unsigned char val)
@@ -70,7 +80,7 @@ void cN2Timer::Ctrl(unsigned char val)
     ctrl=(ctrl&~tmRUNNING) | (val&tmRUNNING);
     if(!Running()) {
       Stop();
-      PRINTF(L_SYS_EMU,"n2timer: stopped cycles=%x ctrl=%x",cycles,ctrl);
+      PRINTF(L_SYS_EMU,"n2timer %d: stopped cycles=%x ctrl=%x",nr,cycles,ctrl);
       }
     }
   else {
@@ -80,7 +90,7 @@ void cN2Timer::Ctrl(unsigned char val)
       else divisor=4; // This is wrong, but we haven't figured the right value out yet
       if(divisor<=0) divisor=1; // sanity
       if(!(ctrl&tmLATCHED)) cycles=(unsigned int)(cycles-1)&0xFF;
-      PRINTF(L_SYS_EMU,"n2timer: started latch=%x div=%d cycles=%x ctrl=%x",latch,divisor,cycles,ctrl);
+      PRINTF(L_SYS_EMU,"n2timer %d: started latch=%x div=%d cycles=%x ctrl=%x",nr,latch,divisor,cycles,ctrl);
       remainder=-1;
       if(!(ctrl&tmCONTINUOUS) && cycles==0) ctrl&=~tmRUNNING;
       }
@@ -92,40 +102,98 @@ void cN2Timer::Stop(void)
   ctrl&=~(tmRUNNING|tmLATCHED);
 }
 
-// -- cMapMemHW ----------------------------------------------------------------
+// -- cN2CRC -------------------------------------------------------------------
 
 #define CRC_POLY 0x8408 // ccitt poly
 
-cMapMemHW::cMapMemHW(void)
-:cMapMem(HW_OFFSET,HW_REGS)
+cN2CRC::cN2CRC(void)
 {
-  cycles=0;
-  CRCvalue=0xffff; CRCpos=0; CRCstarttime=0; CRCinput=0; CRCupdate=false;
-  GenCRC16Table();
-  PRINTF(L_SYS_EMU,"mapmemhw: new HW map off=%04x size=%04x",offset,size);
+  cycles=0; CRCpos=0; CRCtime=0; CRCin=0;
+  CRCvalue=0xffff; CRCit=CRCCALC_DELAY+1; ctrl=CRC_DISABLED;
+  GenTable();
 }
 
-void cMapMemHW::GenCRC16Table(void)
+void cN2CRC::AddCycles(unsigned int num)
+{
+  cycles+=num;
+}
+
+void cN2CRC::GenTable(void)
 {
   for(int i=0; i<256; i++) {
     unsigned short c=i;
     for(int j=0; j<8; j++) c=(c>>1)^((c&1)?CRC_POLY:0);
-    crc16table[i]=c;
+    table[i]=c;
     }
 }
 
-unsigned short cMapMemHW::CRC(unsigned short crc, unsigned char val, int bits)
+void cN2CRC::Update(void)
 {
-  if(bits>=8) return (crc>>8)^crc16table[(crc^val)&0xff];
-  if(bits>0) crc^=(val&(0xff>>(8-bits)));
-  for(int i=0; i<bits; i++) crc=(crc>>1)^((crc&1)?CRC_POLY:0);
-  return crc;
+  if(!(ctrl&CRC_DISABLED) && CRCit<=CRCCALC_DELAY) {
+    unsigned int it=CRCit;
+    CRCit+=cycles-CRCtime;
+    if(CRCit>CRCCALC_DELAY)  // > instead of >= because of CRC_BUSY lockout
+      CRCit=CRCCALC_DELAY+1;
+    if(it==0 && CRCit>=CRCCALC_DELAY)
+      CRCvalue=(CRCvalue>>8)^table[(CRCvalue^CRCin)&0xff];
+    else
+      for(; it<CRCit && it<CRCCALC_DELAY; it++)
+        CRCvalue=(CRCvalue>>1) ^ (((CRCvalue^(CRCin>>it))&1) ? CRC_POLY : 0);
+    CRCtime=cycles;
+    }
 }
 
-void cMapMemHW::AddCycles(unsigned int num)
+unsigned char cN2CRC::Ctrl(void)
 {
-  cycles+=num;
-  for(int i=0; i<MAX_TIMERS; i++) timer[i].AddCycles(num);
+  Update();
+  unsigned char r=ctrl;
+  if(CRCit<CRCCALC_DELAY) r|=CRC_BUSY; else r&=~CRC_BUSY;
+  return r|0x80;
+}
+
+void cN2CRC::Ctrl(unsigned char c)
+{
+  if(ctrl&CRC_DISABLED) {
+    if(!(c&CRC_DISABLED)) {
+      CRCvalue=0xffff; CRCpos=0; CRCtime=cycles;
+      if(CRCit<=CRCCALC_DELAY) { CRCtime++; CRCit++; }
+      }
+    }
+  else if(c&CRC_DISABLED) Update();
+  ctrl=c;
+}
+
+unsigned char cN2CRC::Data(void)
+{
+  Update();
+  return (CRCvalue^0xffff)>>((CRCpos++&1)<<3);
+}
+
+void cN2CRC::Data(unsigned char d)
+{
+  Update();
+  if(CRCit>CRCCALC_DELAY && !(ctrl&CRC_DISABLED)) {
+    CRCin=d;
+    CRCit=0; CRCtime=cycles;
+    }
+}
+
+// -- cMapMemHW ----------------------------------------------------------------
+
+cMapMemHW::cMapMemHW(void)
+:cMapMem(HW_OFFSET,HW_REGS)
+{
+  for(int i=0; i<MAX_TIMERS; i++) timer[i].SetNumber(HW_NUM(i));
+  PRINTF(L_SYS_EMU,"mapmemhw: new HW map off=%04x size=%04x",offset,size);
+}
+
+int cMapMemHW::AddCycles(unsigned int num)
+{
+  crc.AddCycles(num);
+  int mask=0;
+  for(int i=0; i<MAX_TIMERS; i++)
+    if(timer[i].AddCycles(num)) mask|=1<<timer[i].Number();
+  return mask;
 }
 
 unsigned char cMapMemHW::Get(unsigned short ea)
@@ -148,26 +216,9 @@ unsigned char cMapMemHW::Get(unsigned short ea)
     case HW_TIMER2_LATCH:
       return timer[TIMER_NUM(ea)].Latch();
     case HW_CRC_CONTROL:
-      {
-      unsigned char r=mem[ea];
-      if(!(r&CRC_DISABLED) && cycles-CRCstarttime<CRCCALC_DELAY) r|=CRC_BUSY; // busy
-      else r&=~CRC_BUSY; // not busy
-      return r;
-      }
+      return crc.Ctrl();
     case HW_CRC_DATA:
-      {
-      unsigned short crc;
-      if(CRCupdate) {
-        crc=CRC(CRCvalue,CRCinput,cycles-CRCstarttime-1);
-        if(cycles-CRCstarttime>=CRCCALC_DELAY) {
-          CRCvalue=crc; CRCupdate=false;
-          }
-        }
-      else crc=CRCvalue;
-      unsigned char r=(crc^0xffff)>>((CRCpos&1)<<3);
-      CRCpos^=1;
-      return r;
-      }
+      return crc.Data();
     default:
       return mem[ea];
     }
@@ -189,24 +240,10 @@ void cMapMemHW::Set(unsigned short ea, unsigned char val)
       timer[TIMER_NUM(ea)].Latch(val);
       break;
     case HW_CRC_CONTROL:
-      if((mem[ea]&CRC_DISABLED) && !(val&CRC_DISABLED)) {
-        CRCvalue=0xffff; CRCinput=0; CRCpos=0; CRCupdate=false;
-        CRCstarttime=cycles-CRCCALC_DELAY;
-        }
-      mem[ea]=val;
+      crc.Ctrl(val);
       break;
     case HW_CRC_DATA:
-      if(cycles-CRCstarttime>=CRCCALC_DELAY) {
-        if(CRCupdate) {
-          CRCvalue=CRC(CRCvalue,CRCinput,8);
-          CRCupdate=false;
-          }
-        if(!(mem[HW_CRC_CONTROL]&CRC_DISABLED)) {
-          CRCinput=val;
-          CRCupdate=true;
-          CRCstarttime=cycles;
-          }
-        }
+      crc.Data(val);
       break;
     default:
       mem[ea]=val;
@@ -248,11 +285,116 @@ bool cN2Emu::Init(int id, int romv)
   return initDone;
 }
 
+// -- cMapReg ------------------------------------------------------------------
+
+cMapReg::cMapReg(int *_defwordsize, int _maxwordsize)
+{
+  SetDefWordSize(_defwordsize);
+  SetMaxWordSize(_maxwordsize);
+  wordsize=DEF_WORDSIZE;
+}
+
+BIGNUM *cMapReg::Value(int wsize, bool mask)
+{
+  wsize=OpWordSize(wsize);
+  if(wordsize!=wsize) {
+    Commit();
+    Reload();
+    }
+  else if(mask)
+    BN_mask_bits(reg,wsize*64);
+  return reg;
+}
+
+void cMapReg::ClearReg(int wsize)
+{
+  BN_rshift(reg,reg,wsize*64);
+  BN_lshift(reg,reg,wsize*64);
+}
+
+void cMapReg::ClearFullReg(int wsize)
+{
+  BN_rshift(fullreg,fullreg,wsize*64);
+  BN_lshift(fullreg,fullreg,wsize*64);
+}
+
+void cMapReg::PrepTmp(BIGNUM *val, int wsize)
+{
+  if(val->neg) {
+    BN_clear(tmp);
+    BN_set_bit(tmp,wsize*64);
+    BN_add(tmp,tmp,val);
+    }
+  else
+    BN_copy(tmp,val);
+  BN_mask_bits(tmp,wsize*64);
+}
+
+void cMapReg::Commit(int wsize, int resync)
+{
+  if(resync<0 && wsize<0) resync=1;
+  wsize=OpWordSize(wsize>=0?wsize:wordsize);
+  ClearFullReg(wsize);
+  PrepTmp(reg,wsize);
+  BN_add(fullreg,fullreg,tmp);
+  if(resync) {
+    if(wordsize==wsize) BN_mask_bits(reg,wsize*64);
+    else wordsize=wsize;
+    }
+}
+
+void cMapReg::Reload(int wsize)
+{
+  wsize=OpWordSize(wsize>=0?wsize:wordsize);
+  wordsize=wsize;
+  BN_copy(reg,fullreg);
+  BN_mask_bits(reg,64*wsize);
+}
+
+void cMapReg::GetLE(const unsigned char *in, int n)
+{
+  int wsize=OpWordSize(n<=0?n:(n+7)/8);
+  if(wordsize>wsize) Commit();
+  reg.GetLE(in,wsize*8);
+  Commit(wsize);
+}
+
+void cMapReg::PutLE(unsigned char *out, int n)
+{
+  int wsize=OpWordSize(n<=0?n:(n+7)/8);
+  Commit();
+  fullreg.PutLE(out,wsize*8);
+}
+
+void cMapReg::Set(BIGNUM *val, int wsize)
+{
+  wsize=OpWordSize(wsize);
+  if(wordsize!=wsize) Commit();
+  ClearReg(wsize);
+  PrepTmp(val,wsize);
+  if(wordsize!=wsize) {
+    ClearFullReg(wsize);
+    BN_add(fullreg,fullreg,tmp);
+    }
+  BN_add(reg,reg,tmp);
+}
+
+void cMapReg::Clear(int wsize)
+{
+  wsize=OpWordSize(wsize);
+  if(wordsize!=wsize) {
+    Commit();
+    ClearFullReg(wsize);
+    }
+  ClearReg(wsize);
+}
+
 // -- cMapMath -----------------------------------------------------------------
 
 cMapMath::cMapMath(void)
+:A(&wordsize),B(&wordsize),C(&wordsize),D(&wordsize),J(0,1),I(&wordsize)
 {
-  wordsize=DEF_WORDSIZE;
+  wordsize=DEF_WORDSIZE; words=-1;
 }
 
 bool cMapMath::ModAdd(BIGNUM *r, BIGNUM *a, BIGNUM *b, BIGNUM *d)
@@ -277,16 +419,23 @@ bool cMapMath::ModSub(BIGNUM *r, BIGNUM *d, BIGNUM *b)
   return ret;
 }
 
-void cMapMath::MakeJ0(BIGNUM *j, BIGNUM *d, int bits)
+void cMapMath::MakeJ0(BIGNUM *j, BIGNUM *d, BIGNUM *c, int bits)
 {
 #if OPENSSL_VERSION_NUMBER < 0x0090700fL
 #error BN_mod_inverse is probably buggy in your openssl version
 #endif
   BN_zero(x);
-  BN_sub(j,x,d);
+  BN_sub(j,x,d); j->neg=1;
   BN_set_bit(j,0);
   BN_set_bit(x,bits);
   BN_mod_inverse(j,j,x,ctx);
+  if(c) {
+    BN_copy(c,d);
+    BN_mask_bits(c,bits);
+    BN_mul(c,j,c,ctx);
+    BN_rshift(c,c,bits);
+    BN_mask_bits(c,bits);
+    }
 }
 
 void cMapMath::MonMul(BIGNUM *o, BIGNUM *a, BIGNUM *b)
@@ -300,6 +449,12 @@ void cMapMath::MonMul(BIGNUM *o, BIGNUM *a, BIGNUM *b, int w)
 }
 
 void cMapMath::MonMul(BIGNUM *o, BIGNUM *a, BIGNUM *b, BIGNUM *c, BIGNUM *d, BIGNUM *j, int w)
+{
+  MonMul0(o,a,b,c,d,j,w);
+  MonFin(o,d);
+}
+
+void cMapMath::MonMul0(BIGNUM *o, BIGNUM *a, BIGNUM *b, BIGNUM *c, BIGNUM *d, BIGNUM *j, int w)
 {
   if(!w) w=wordsize;
   MonStart(w);
@@ -350,20 +505,23 @@ void cMapMath::MonLoop(BIGNUM *o, BIGNUM *a, BIGNUM *b, BIGNUM *c, BIGNUM *d, BI
     }
 
   BN_rshift(s,s,64);
-  if(BN_cmp(s,d)==1) {
-    BN_copy(x,s);
-    BN_sub(s,x,d);
-    }
-
+  if(words) MonFin(s,d);
   if(!words) BN_copy(o,s);
 }
 
+void cMapMath::MonFin(BIGNUM *s, BIGNUM *d)
+{
+  if(BN_cmp(s,d)>=0)
+    BN_sub(s,s,d);
+}
+
 // -- cMapCore -----------------------------------------------------------------
 
 cMapCore::cMapCore(void)
 {
-  last=1;
+  last=1; mapid=0;
   regs[0]=&J; regs[1]=&A; regs[2]=&B; regs[3]=&C; regs[4]=&D;
+  interruptible=false;
 }
 
 void cMapCore::MonInit(int bits)
@@ -376,6 +534,18 @@ void cMapCore::MonInit(int bits)
   for(int i=0; i<4; i++) MonMul(B,B,B);
 }
 
+void cMapCore::MonExp(BIGNUM *scalar)
+{
+  if(BN_is_zero(D)) { BN_one(A); return; }
+  BN_copy(A,B);
+  for(int i=BN_num_bits(scalar)-2; i>-1; i--) {
+    MonMul(B,B,B);
+    if(BN_is_bit_set(scalar,i)) MonMul(B,A,B);
+    }
+  BN_one(A);
+  MonMul(B,A,B);
+}
+
 void cMapCore::MonExpNeg(void)
 {
   if(BN_is_zero(D)) { BN_set_word(A,1); return; }
@@ -519,11 +689,32 @@ int cMapCore::GetOpSize(int l)
   return l!=0 ? l : wordsize;
 }
 
-bool cMapCore::DoMap(int f, unsigned char *data, int l)
+void cMapCore::DoMap(int f, unsigned char *data, int l)
+{
+  PRINTF(L_SYS_MAP,"%04x: calling function %02X",mapid,f);
+  cycles=0;
+  unsigned int startcycles=CpuCycles();
+  interrupted=false; interruptible=true;
+  try {
+    if(!Map(f,data,l) && !MapGeneric(f,data,l))
+      PRINTF(L_SYS_MAP,"%04x: unsupported call %02x",mapid,f);
+    if(cycles) {
+      unsigned int elapsed=CpuCycles()-startcycles;
+      if(cycles>elapsed) AddMapCycles(cycles-elapsed);
+      }
+    }
+  catch(int) {
+    interrupted=true;
+    PRINTF(L_SYS_MAP,"%04x: call %02x interrupted (%d cycles)",mapid,f,CpuCycles()-startcycles);
+    }
+  interruptible=false;
+  cycles=CpuCycles()-startcycles;
+}
+
+bool cMapCore::MapGeneric(int f, unsigned char *data, int l)
 {
   const int l1=GetOpSize(l);
   const int dl=l1<<3;
-  cycles=0;
   switch(f) {
     case SETSIZE:
       cycles=(l>17 ? 459 : (l ? 475 : 454))-6;
@@ -582,7 +773,7 @@ bool cMapCore::DoMap(int f, unsigned char *data, int l)
       last=f-SWAP_A+1;
       e.GetLE(data,dl);
       regs[last]->PutLE(data,dl);
-      BN_copy(*regs[last],e);
+      regs[last]->Set(e,l1);
       break;
 
     case CLEAR_A:
@@ -590,22 +781,54 @@ bool cMapCore::DoMap(int f, unsigned char *data, int l)
     case CLEAR_C:
     case CLEAR_D:
       cycles=462+(8*l1+3)/5*5-6;
-      last=f-CLEAR_A+1; BN_zero(*regs[last]);
+      last=f-CLEAR_A+1;
+      regs[last]->Clear(l1);
       break;
 
     case COPY_A_B:
-      last=2; BN_copy(B,A); cycles=462+(8*l1+3)/5*5-6; break;
+      last=2; B.Set(A,l1); cycles=462+(8*l1+3)/5*5-6; break;
     case COPY_B_A:
-      last=1; BN_copy(A,B); cycles=462+(8*l1+3)/5*5-6; break;
+      last=1; A.Set(B,l1); cycles=462+(8*l1+3)/5*5-6; break;
     case COPY_A_C:
-      last=3; BN_copy(C,A); cycles=462+(8*l1+3)/5*5-6; break;
+      last=3; C.Set(A,l1); cycles=462+(8*l1+3)/5*5-6; break;
     case COPY_C_A:
-      last=1; BN_copy(A,C); cycles=462+(8*l1+3)/5*5-6; break;
+      last=1; A.Set(C,l1); cycles=462+(8*l1+3)/5*5-6; break;
     case COPY_C_D:
-      last=4; BN_copy(D,C); cycles=462+(8*l1+3)/5*5-6; break;
+      last=4; D.Set(C,l1); cycles=462+(8*l1+3)/5*5-6; break;
     case COPY_D_C:
-      last=3; BN_copy(C,D); cycles=462+(8*l1+3)/5*5-6; break;
+      last=3; C.Set(D,l1); cycles=462+(8*l1+3)/5*5-6; break;
 
+    case 0x39:
+      WS_START(1);
+      MakeJ0(J,D,C);
+      AddMapCycles(860);
+      BN_zero(C);
+      WS_END();
+      if(!BN_is_zero(D)) {
+        BN_zero(I);
+        BN_set_bit(I,68*wordsize);
+        BN_mod(B,I,D,ctx);
+        }
+      AddMapCycles(1370);
+      for(int i=0; i<4; i++) MonMul(B,B,B);
+//        MonInit();
+      I.GetLE(data,wordsize<<3);
+      MonMul(B,I,B);
+      MonMul(B,A,B);
+      break;
+    case 0x3a:
+      MakeJ0(J,D);
+      if(!BN_is_zero(D)) {
+        BN_zero(I);
+        BN_set_bit(I,68*wordsize);
+        BN_mod(B,I,D,ctx);
+        }
+      AddMapCycles(2000);
+      for(int i=0; i<4; i++) MonMul(B,B,B);
+//        MonInit();
+      MonMul(B,A,B);
+      MonMul(B,A,B);
+      break;
     case 0x43: // init SHA1
       SHA1_Init(&sctx);
       break;
