@@ -57,7 +57,7 @@ cTtxtSubsChannelSettings TtxtSubsChannelSettings;
 // XXX should be replaced with something that allows for other languages and for real language names!
 // <http://www.avio-systems.com/dtvcc/iso639-2.txt>
 // <http://www.loc.gov/standards/iso639-2/englangn_ascii.html>
-char *gLanguages[][2] = { 
+const char *gLanguages[][2] = { 
   {"",""},       //None
   {"eng",""},    //English
   {"deu","ger"}, //Deutsch
@@ -745,7 +745,7 @@ cMenuSetupTtxtsubs::cMenuSetupTtxtsubs(cPluginTtxtsubs *ttxtsubs, int doStore)
 
   for(int n = 0; n < MAXLANGUAGES; n++) {
     char str[100];
-    char *allowedc = "abcdefghijklmnopqrstuvwxyz";
+    const char *allowedc = "abcdefghijklmnopqrstuvwxyz";
 
     cOsdItem *item = new cOsdItem("--------------------------------------------------------");
     item->SetSelectable(false);
