@@ -213,7 +213,7 @@ cSetup Setup;
 
 cSetup::cSetup(void)
 {
-  CutTimePatchEnabled = 0;
+  CutTimePatchEnabled = 1;
   strcpy(OSDLanguage, ""); // default is taken from environment
   strcpy(OSDSkin, "sttng");
   strcpy(OSDTheme, "default");
@@ -226,6 +226,10 @@ cSetup::cSetup(void)
   MarkInstantRecord = 1;
   strcpy(NameInstantRecord, "TITLE EPISODE");
   InstantRecordTime = 180;
+//ML
+  VerboseLNBlog = 0;
+  for (int i = 0; i < MAXDEVICES; i++) CardUsesLNBnr[i] = i + 1;
+//ML-End
   LnbSLOF    = 11700;
   LnbFrequLo =  9750;
   LnbFrequHi = 10600;
@@ -261,6 +265,8 @@ cSetup::cSetup(void)
   UseVps = 0;
   VpsMargin = 120;
   RecordingDirs = 1;
+  RecordingsSortMode = 0;
+  RecordingsSortDirsFirst = 0;
   VideoDisplayFormat = 1;
   VideoFormat = 0;
   UpdateChannels = 5;
@@ -309,10 +315,6 @@ cSetup::cSetup(void)
   ShowRecLength = 0;
   ShowProgressBar = 0;
   MenuCmdPosition = 0;
-//ML
-  VerboseLNBlog = 0;
-  for (int i = 0; i < MAXDEVICES; i++) CardUsesLNBnr[i] = i + 1;
-//ML-End
 }
 
 cSetup& cSetup::operator= (const cSetup &s)
@@ -457,6 +459,8 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "UseVps"))              UseVps             = atoi(Value);
   else if (!strcasecmp(Name, "VpsMargin"))           VpsMargin          = atoi(Value);
   else if (!strcasecmp(Name, "RecordingDirs"))       RecordingDirs      = atoi(Value);
+  else if (!strcasecmp(Name, "RecordingsSortMode"))  RecordingsSortMode = atoi(Value);
+  else if (!strcasecmp(Name, "RecordingsSortDirsFirst")) RecordingsSortDirsFirst = atoi(Value);
   else if (!strcasecmp(Name, "VideoDisplayFormat"))  VideoDisplayFormat = atoi(Value);
   else if (!strcasecmp(Name, "VideoFormat"))         VideoFormat        = atoi(Value);
   else if (!strcasecmp(Name, "UpdateChannels"))      UpdateChannels     = atoi(Value);
@@ -539,6 +543,16 @@ bool cSetup::Save(void)
   Store("MarkInstantRecord",  MarkInstantRecord);
   Store("NameInstantRecord",  NameInstantRecord);
   Store("InstantRecordTime",  InstantRecordTime);
+//ML
+  Store("VerboseLNBlog",       VerboseLNBlog);
+  char tmp[20];
+  if (cDevice::NumDevices() > 1) {
+     for (int i = 1; i <= cDevice::NumDevices(); i++) {
+         sprintf(tmp, "Card%dusesLNBnr", i);
+         Store(tmp, CardUsesLNBnr[i - 1]);
+         }
+     }
+//ML-End
   Store("LnbSLOF",            LnbSLOF);
   Store("LnbFrequLo",         LnbFrequLo);
   Store("LnbFrequHi",         LnbFrequHi);
@@ -574,6 +588,8 @@ bool cSetup::Save(void)
   Store("UseVps",             UseVps);
   Store("VpsMargin",          VpsMargin);
   Store("RecordingDirs",      RecordingDirs);
+  Store("RecordingsSortMode", RecordingsSortMode);
+  Store("RecordingsSortDirsFirst", RecordingsSortDirsFirst);
   Store("VideoDisplayFormat", VideoDisplayFormat);
   Store("VideoFormat",        VideoFormat);
   Store("UpdateChannels",     UpdateChannels);
@@ -623,16 +639,6 @@ bool cSetup::Save(void)
   Store("ShowProgressBar",    ShowProgressBar);
   Store("MenuCmdPosition",    MenuCmdPosition);
   Store("CutTimePatchEnabled",CutTimePatchEnabled);
-//ML
-  Store("VerboseLNBlog",       VerboseLNBlog);
-  char tmp[20];
-  if (cDevice::NumDevices() > 1) {
-     for (int i = 1; i <= cDevice::NumDevices(); i++) {
-         sprintf(tmp, "Card%dusesLNBnr", i);
-         Store(tmp, CardUsesLNBnr[i - 1]);
-         }
-     }
-//ML-End
 
   Sort();
 
