@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: font.c 1.22 2007/11/04 11:08:12 kls Exp $
+ * $Id: font.c 1.25.1.1 2008/05/03 09:59:24 kls Exp $
  */
 
 #include "font.h"
@@ -184,6 +184,10 @@ int cFreetypeFont::Kerning(cGlyph *Glyph, uint PrevSym) const
 
 cGlyph* cFreetypeFont::Glyph(uint CharCode, bool AntiAliased) const
 {
+  // Non-breaking space:
+  if (CharCode == 0xA0)
+     CharCode = 0x20;
+
   // Lookup in cache:
   cList<cGlyph> *glyphCache = AntiAliased ? &glyphCacheAntiAliased : &glyphCacheMonochrome;
   for (cGlyph *g = glyphCache->First(); g; g = glyphCache->Next(g)) {
@@ -214,6 +218,9 @@ cGlyph* cFreetypeFont::Glyph(uint CharCode, bool AntiAliased) const
         return Glyph;
         }
      }
+#define UNKNOWN_GLYPH_INDICATOR '?'
+  if (CharCode != UNKNOWN_GLYPH_INDICATOR)
+     return Glyph(UNKNOWN_GLYPH_INDICATOR, AntiAliased);
   return NULL;
 }
 
@@ -241,10 +248,16 @@ int cFreetypeFont::Width(const char *s) const
   return w;
 }
 
+#define MAX_BLEND_LEVELS 256
+
 void cFreetypeFont::DrawText(cBitmap *Bitmap, int x, int y, const char *s, tColor ColorFg, tColor ColorBg, int Width) const
 {
   if (s && height) { // checking height to make sure we actually have a valid font
      bool AntiAliased = Setup.AntiAlias && Bitmap->Bpp() >= 8;
+     bool TransparentBackground = ColorBg == clrTransparent;
+     int16_t BlendLevelIndex[MAX_BLEND_LEVELS]; // tIndex is 8 bit unsigned, so a negative value can be used to mark unused entries
+     if (AntiAliased && !TransparentBackground)
+        memset(BlendLevelIndex, 0xFF, sizeof(BlendLevelIndex)); // initializes the array with negative values
      tIndex fg = Bitmap->Index(ColorFg);
      uint prevSym = 0;
      while (*s) {
@@ -252,6 +265,8 @@ void cFreetypeFont::DrawText(cBitmap *Bitmap, int x, int y, const char *s, tColo
            uint sym = Utf8CharGet(s, sl);
            s += sl;
            cGlyph *g = Glyph(sym, AntiAliased);
+           if (!g)
+              continue;
            int kerning = Kerning(g, prevSym);
            prevSym = sym;
            uchar *buffer = g->Bitmap();
@@ -266,12 +281,16 @@ void cFreetypeFont::DrawText(cBitmap *Bitmap, int x, int y, const char *s, tColo
                          if (bt > 0x00) {
                             int px = x + pitch + g->Left() + kerning;
                             int py = y + row + (height - Bottom() - g->Top());
+                            tColor bg;
                             if (bt == 0xFF)
-                               Bitmap->SetIndex(px, py, fg);
-                            else {
-                               tColor bg = (ColorBg != clrTransparent) ? ColorBg : Bitmap->GetColor(px, py);
-                               Bitmap->SetIndex(px, py, Bitmap->Index(Bitmap->Blend(ColorFg, bg, bt)));
-                               }
+                               bg = fg;
+                            else if (TransparentBackground)
+                               bg = Bitmap->Index(Bitmap->Blend(ColorFg, Bitmap->GetColor(px, py), bt));
+                            else if (BlendLevelIndex[bt] >= 0)
+                               bg = BlendLevelIndex[bt];
+                            else
+                               bg = BlendLevelIndex[bt] = Bitmap->Index(Bitmap->Blend(ColorFg, ColorBg, bt));
+                            Bitmap->SetIndex(px, py, bg);
                             }
                          }
                       else { //monochrome rendering
@@ -376,7 +395,7 @@ bool cFont::GetAvailableFontNames(cStringList *FontNames, bool Monospaced)
      FcFontSetDestroy(fontset);
      FcPatternDestroy(pat);
      FcObjectSetDestroy(os);
-     FcFini();
+     //FcFini(); // older versions of fontconfig are broken - and FcInit() can be called more than once
      FontNames->Sort();
      }
   return FontNames->Size() > 0;
@@ -412,7 +431,7 @@ cString cFont::GetFontFileName(const char *FontName)
         esyslog("ERROR: no usable font found for '%s'", FontName);
      FcPatternDestroy(pat);
      free(fn);
-     FcFini();
+     //FcFini(); // older versions of fontconfig are broken - and FcInit() can be called more than once
      }
   return FontFileName;
 }
