@@ -34,6 +34,7 @@ class IMenuItemDefinition
         virtual ~IMenuItemDefinition() {};
         virtual bool IsCustomOsdItem() = 0;
         virtual bool IsPluginItem() = 0;
+        virtual bool IsSeparatorItem() = 0;
         virtual cOsdItem* CustomOsdItem() = 0;
         virtual const char* PluginMenuEntry() = 0;
         virtual bool IsSelected() = 0;
@@ -42,7 +43,7 @@ class IMenuItemDefinition
 
 typedef std::vector<IMenuItemDefinition*> MenuItemDefinitions;
 
-#define MENU_ITEMS_PROVIDER_SERVICE_ID "MenuOrgPatch-v0.4::MainMenuItemsProvider"
+#define MENU_ITEMS_PROVIDER_SERVICE_ID "MenuOrgPatch-v0.4.2::MainMenuItemsProvider"
 
 class IMainMenuItemsProvider
 {
