@@ -10,6 +10,7 @@
 #ifndef __RECORDER_H
 #define __RECORDER_H
 
+#include "livebuffer.h"
 #include "receiver.h"
 #include "recording.h"
 #include "remux.h"
@@ -24,12 +25,15 @@ private:
   cRingBufferLinear *ringBuffer;
   cRemux *remux;
   cFileWriter *writer;
+  char *fileName;
+  cLiveBuffer *liveBuffer;
+  cTtxtSubsRecorderBase *ttxtSubsRecorder;
 protected:
   virtual void Activate(bool On);
   virtual void Receive(uchar *Data, int Length);
   virtual void Action(void);
 public:
-  cRecorder(const char *FileName, tChannelID ChannelID, int Priority, int VPid, const int *APids, const int *DPids, const int *SPids, cTtxtSubsRecorderBase *tsr);
+  cRecorder(const char *FileName, tChannelID ChannelID, int Priority, int VPid, const int *APids, const int *DPids, const int *SPids, cTtxtSubsRecorderBase *tsr, cLiveBuffer *LiveBuffer = NULL);
                // Creates a new recorder for the channel with the given ChannelID and
                // the given Priority that will record the given PIDs into the file FileName.
   virtual ~cRecorder();
