@@ -63,12 +63,16 @@ public:
   bool Write(FILE *f, const char *Prefix = "") const;
   };
 
+#define SORTRECORDINGSVERSNUM 3
+#define MAXSORTMODES 4
+
 class cRecording : public cListObject {
   friend class cRecordings;
 private:
   mutable int resume;
   mutable char *titleBuffer;
-  mutable char *sortBuffer;
+  mutable char *sortBuffer[MAXSORTMODES];
+  mutable char lastDirsFirst[MAXSORTMODES];
   mutable char *fileName;
   mutable char *name;
   mutable int fileSizeMB;
@@ -119,6 +123,7 @@ private:
   bool deleted;
   time_t lastUpdate;
   int state;
+  int SortOrder;
   const char *UpdateFileName(void);
   void Refresh(bool Foreground = false);
   void ScanVideoDir(const char *DirName, bool Foreground = false, int LinkLevel = 0);
@@ -149,6 +154,8 @@ public:
   void AddByName(const char *FileName, bool TriggerUpdate = true);
   void DelByName(const char *FileName);
   int TotalFileSizeMB(void); ///< Only for deleted recordings!
+  void ToggleSortOrder(void) { SortOrder *= -1; }
+  const int GetSortOrder(void) { return SortOrder; }
   };
 
 extern cRecordings Recordings;
@@ -201,7 +208,7 @@ public:
 // 'I' frame, to have a complete Group Of Pictures):
 #define MAXVIDEOFILESIZE 2000 // MB
 #define MINVIDEOFILESIZE    1 // MB
-
+ 
 #define MINRECORDINGSIZE      25 // GB
 #define MAXRECORDINGSIZE     500 // GB
 #define DEFAULTRECORDINGSIZE 100 // GB
