@@ -22,7 +22,7 @@
  *
  * The project's page is at http://www.cadsoft.de/vdr
  *
- * $Id: vdr.c 1.313 2008/03/14 13:22:39 kls Exp $
+ * $Id: vdr.c 1.313.1.1 2008/09/06 11:07:52 kls Exp $
  */
 
 #include <getopt.h>
@@ -142,7 +142,6 @@ static bool SetKeepCaps(bool On)
 
 static void SignalHandler(int signum)
 {
-  isyslog("caught signal %d", signum);
   switch (signum) {
     case SIGPIPE:
          break;
@@ -404,7 +403,7 @@ int main(int argc, char *argv[])
         printf("Usage: vdr [OPTIONS]\n\n"          // for easier orientation, this is column 80|
                "  -a CMD,   --audio=CMD    send Dolby Digital audio to stdin of command CMD\n"
                "  -b DIR,   --buffer=DIR   use DIR as LiveBuffer directory (default is to write\n"
-               "                           it to the video directory)\n"
+               "                           it to the video directory)\n" 
                "  -c DIR,   --config=DIR   read config files from DIR (default: %s)\n"
                "  -d,       --daemon       run in daemon mode\n"
                "  -D NUM,   --device=NUM   use only the given DVB device (NUM = 0, 1, 2...)\n"
@@ -807,7 +806,7 @@ int main(int argc, char *argv[])
               if (cControl::Control(true))
                  cControl::Control(true)->Hide();
               Menu = new cDisplayChannel(cDevice::CurrentChannel(), LastChannel >= 0);
-	      }
+              }
            LastChannel = cDevice::CurrentChannel();
            LastChannelChanged = Now;
            }
@@ -1017,7 +1016,7 @@ int main(int argc, char *argv[])
                   if (cControl::Control(true))
                      cControl::Control(true)->Hide();
                   Menu = new cDisplayChannel(NORMALKEY(key));
-		  }
+                  }
                else if (cDisplayChannel::IsOpen() || cControl::Control()) {
                   Interact->ProcessKey(key);
                   continue;
@@ -1240,7 +1239,7 @@ int main(int argc, char *argv[])
              default:    break;
              }
            }
-	   }
+           }
         if (!Menu) {
            if (!InhibitEpgScan)
               EITScanner.Process();
@@ -1333,9 +1332,11 @@ Exit:
   ReportEpgBugFixStats();
   if (WatchdogTimeout > 0)
      dsyslog("max. latency time %d seconds", MaxLatencyTime);
-  isyslog("exiting, exit code %d", ShutdownHandler.GetExitCode());
+  if (LastSignal)
+     isyslog("caught signal %d", LastSignal);
   if (ShutdownHandler.EmergencyExitRequested())
      esyslog("emergency exit!");
+  isyslog("exiting, exit code %d", ShutdownHandler.GetExitCode());
   if (SysLogLevel > 0)
      closelog();
   if (HasStdin)
